{
  "": {
    "domain": "ckan",
    "lang": "lt",
    "plural-forms": "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);"
  },
  "An Error Occurred": [
    null,
    "Įvyko klaida"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Ar tikrai norite atlikti šį veiksmą?"
  ],
  "Cancel": [
    null,
    "Atšaukti"
  ],
  "Confirm": [
    null,
    "Patvirtinti"
  ],
  "Edit": [
    null,
    "Redaguoti"
  ],
  "Failed to load data API information": [
    null,
    "Nepavyko įkelti duomenų API informacijos"
  ],
  "Follow": [
    null,
    "Sekti"
  ],
  "Hide": [
    null,
    "Paslėpti"
  ],
  "Image": [
    null,
    "Paveikslėlis"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "",
    "",
    "",
    ""
  ],
  "Loading...": [
    null,
    "Kraunama..."
  ],
  "No matches found": [
    null,
    "Atitikmenų nerasta"
  ],
  "Please Confirm Action": [
    null,
    "Prašome patvirtinti veiksmą"
  ],
  "Remove": [
    null,
    "Pašalinti"
  ],
  "Resource uploaded": [
    null,
    "Išteklius įkeltas"
  ],
  "Show more": [
    null,
    "Rodyti daugiau"
  ],
  "Start typing…": [
    null,
    "Pradėkite spausdinti..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Yra neišsaugotų redagacijų šioje formoje"
  ],
  "There is no API data to load for this resource": [
    null,
    "Šiam ištekliui nėra jokių API duomenų, kuriuos būtų galima įkelti"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Nepavyko nustatyti siuntinio tapatybės"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Nepavyko gauti duomenų iš įkelto failo"
  ],
  "Unable to upload file": [
    null,
    "Nepavyko įkelti failo"
  ],
  "Unfollow": [
    null,
    "Nebesekti"
  ],
  "Upload": [
    null,
    "Nusiųsti"
  ],
  "Upload a file": [
    null,
    "Įkelti failą"
  ]
}